@@ -3,16 +3,17 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+#undef HAVE_GOBJECT
 #undef HAVE_ODBC
 #undef HAVE_MYSQL
 #undef HAVE_INTERBASE
 #undef HAVE_LDAP
 #undef HAVE_MDB
 #undef HAVE_ORACLE
+#undef HAVE_TDS
 #undef HAVE_SYBASE
 #undef SYBASE_DEBUG
 #undef HAVE_POSTGRES
 #undef HAVE_CAMEL
 #undef USING_GCONF
 #undef USING_OAF
-#undef USING_OLD_OAF
