@@ -1,32 +1,41 @@
-/* GNOME DB libary
+/* GDA client library
  * Copyright (C) 1998,1999 Michael Lausch
  * Copyright (C) 1999,2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
-#include <gda.h>
-#if defined(USING_OAF)
-#  include <liboaf/liboaf.h>
-#else
-#  include <libgnorba/gnorba.h>
-#endif
-#include <gtk/gtkmarshal.h>
+#include "config.h"
+#include "gda-connection.h"
+#include "gda-command.h"
 
-#include <gda-client.h>
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  define _(String) gettext (String)
+#  define N_(String) (String)
+#else
+/* Stubs that do something close enough. */
+#  define textdomain(String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory)
+#  define _(String) (String)
+#  define N_(String) (String)
+#endif
 
 static GHashTable* factories = 0;
 
@@ -42,8 +51,16 @@ enum
 static gint
 gda_connection_signals[LAST_SIGNAL] = {0, };
 
+#ifdef HAVE_GOBJECT
+static void    gda_connection_class_init    (Gda_ConnectionClass *klass,
+                                             gpointer data);
+static void    gda_connection_init          (Gda_Connection *cnc,
+                                             Gda_ConnectionClass *klass);
+#else
 static void    gda_connection_class_init    (Gda_ConnectionClass* klass);
 static void    gda_connection_init          (Gda_Connection* cnc);
+#endif
+
 static void    gda_connection_real_error    (Gda_Connection* cnc, GList*);
 static void    gda_connection_real_warning  (Gda_Connection* cnc, GList*);
 static int     get_corba_connection         (Gda_Connection* cnc);
@@ -61,6 +78,32 @@ gda_connection_real_warning (Gda_Connection* cnc, GList* warnings)
   g_print("%s: %d: %s called\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 }
 
+#ifdef HAVE_GOBJECT
+GType
+gda_connection_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    {
+      GTypeInfo info =
+      {
+        sizeof (Gda_ConnectionClass),               /* class_size */
+	NULL,                                       /* base_init */
+	NULL,                                       /* base_finalize */
+        (GClassInitFunc) gda_connection_class_init, /* class_init */
+	NULL,                                       /* class_finalize */
+	NULL,                                       /* class_data */
+        sizeof (Gda_Connection),                    /* instance_size */
+	0,                                          /* n_preallocs */
+        (GInstanceInitFunc) gda_connection_init,    /* instance_init */
+	NULL,                                       /* value_table */
+      };
+      type = g_type_register_static (G_TYPE_OBJECT, "Gda_Connection", &info);
+    }
+  return type;
+}
+#else
 guint
 gda_connection_get_type (void)
 {
@@ -83,8 +126,19 @@ gda_connection_get_type (void)
     }
   return gda_connection_type;
 }
+#endif
 
-
+#ifdef HAVE_GOBJECT
+static void
+gda_connection_class_init (Gda_ConnectionClass *klass, gpointer data)
+{
+  /* FIXME: No GObject signals yet */
+  klass->error = gda_connection_real_error;
+  klass->warning = gda_connection_real_warning;
+  klass->open = NULL;
+  klass->close = NULL;
+}
+#else
 static void
 gda_connection_class_init (Gda_ConnectionClass* klass)
 {
@@ -123,11 +177,25 @@ gda_connection_class_init (Gda_ConnectionClass* klass)
   klass->close   = NULL;
   klass->open    = NULL;
 }
+#endif
 
 static void
+#ifdef HAVE_GOBJECT
+gda_connection_init (Gda_Connection *cnc, Gda_ConnectionClass *klass)
+#else
 gda_connection_init (Gda_Connection* cnc)
+#endif
 {
-  g_print("%s: %d: %s called\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+  cnc->connection = CORBA_OBJECT_NIL;
+  cnc->commands = NULL;
+  cnc->recordsets = NULL;
+  cnc->provider = NULL;
+  cnc->default_db = NULL;
+  cnc->database = NULL;
+  cnc->user = NULL;
+  cnc->passwd = NULL;
+  cnc->errors_head = NULL;
+  cnc->is_open = FALSE;
 }
 
 static guint
@@ -252,7 +320,11 @@ gda_connection_new (CORBA_ORB orb)
   
   g_return_val_if_fail(orb != NULL, 0);
 
+#ifdef HAVE_GOBJECT
+  cnc = GDA_CONNECTION (g_object_new (GDA_TYPE_CONNECTION, NULL));
+#else
   cnc = gtk_type_new(gda_connection_get_type());
+#endif
   cnc->orb = orb;
   return cnc;
 }
@@ -291,7 +363,11 @@ gda_connection_free (Gda_Connection* cnc)
     g_free(cnc->user);
   if (cnc->passwd)
     g_free(cnc->passwd);
-  g_free(cnc);
+#ifdef HAVE_GOBJECT
+  g_object_unref (G_OBJECT (cnc));
+#else
+  gtk_object_destroy (GTK_OBJECT (cnc));
+#endif
 }  
 
 /**
@@ -481,7 +557,7 @@ gda_connection_open (Gda_Connection* cnc, gchar* dsn, gchar* user, gchar* pwd)
       || rc < 0)
     {
       CORBA_SystemException* sysexc = CORBA_exception_value(&ev);
-      if (sysexc->completed != CORBA_COMPLETED_NO)
+      if (sysexc && sysexc->completed != CORBA_COMPLETED_NO)
         {
           GDA_Connection_close(cnc->connection, &ev);
           CORBA_Object_release(cnc->connection, &ev);
@@ -491,7 +567,9 @@ gda_connection_open (Gda_Connection* cnc, gchar* dsn, gchar* user, gchar* pwd)
     }
   
   cnc->is_open = 1;
+#ifndef HAVE_GOBJECT /* FIXME */
   gtk_signal_emit(GTK_OBJECT(cnc), gda_connection_signals[CONNECTION_OPEN]);
+#endif
   return 0;
 }
 
@@ -523,7 +601,9 @@ gda_connection_close (Gda_Connection* cnc)
   cnc->is_open = 0;
   cnc->connection = CORBA_OBJECT_NIL;
 
+#ifndef HAVE_GOBJECT /* FIXME */
   gtk_signal_emit(GTK_OBJECT(cnc), gda_connection_signals[CONNECTION_CLOSE]);
+#endif
 }
 
 
@@ -548,7 +628,7 @@ open_schema (Gda_Connection* cnc, GDA_Connection_QType t,
   if (gda_connection_corba_exception(cnc, &ev)
       || CORBA_Object_is_nil(rs->field_attributes, &ev))
     {
-      fprintf(stderr," Cannot get recordset description\n");
+      g_print(" Cannot get recordset description\n");
     }
   return rs;
 }
@@ -609,8 +689,8 @@ gda_connection_open_schema_array (Gda_Connection* cnc,
       current++;
     }
   CORBA_exception_init(&ev);
-  fprintf(stderr,"client: gda_connection_open_schema: constraints._maximum = %d\n", constraints->_maximum);
-  fprintf(stderr,"                                    constraints._length  = %d\n", constraints->_length);
+  g_print ("client: gda_connection_open_schema: constraints._maximum = %d\n", constraints->_maximum);
+  g_print ("                                    constraints._length  = %d\n", constraints->_length);
   
   rc = open_schema(cnc, t, constraints);
   CORBA_free(constraints);
@@ -659,7 +739,7 @@ gda_connection_open_schema (Gda_Connection* cnc, GDA_Connection_QType t, ...)
       if (constraint_type == GDA_Connection_no_CONSTRAINT)
         break;
       constraint_value = va_arg(ap, char*);
-      fprintf(stderr,"gda_connection_open_schema: constraint value = '%s'\n", constraint_value);
+      g_print("gda_connection_open_schema: constraint value = '%s'\n", constraint_value);
       c = g_new0(GDA_Connection_Constraint, 1);
       c->ctype = constraint_type;
       c->value = CORBA_string_dup(constraint_value);
@@ -677,7 +757,7 @@ gda_connection_open_schema (Gda_Connection* cnc, GDA_Connection_QType t, ...)
     {
       memcpy(&constraints->_buffer[index], ptr->data,
 	     sizeof(GDA_Connection_Constraint));
-      fprintf(stderr,"CORBA seq: constraint->value = '%s'\n",
+      g_print("CORBA seq: constraint->value = '%s'\n",
               constraints->_buffer[index].value);
       index++;
       count--;
@@ -939,8 +1019,10 @@ gda_connection_add_single_error (Gda_Connection* cnc, Gda_Error* error)
   g_return_if_fail(error != 0);
 
   error_list = g_list_append(error_list, error);
+#ifndef HAVE_GOBJECT /* FIXME */
   gtk_signal_emit(GTK_OBJECT(cnc),
                   gda_connection_signals[CONNECTION_ERROR], error_list);
+#endif
 }
 
 void
@@ -948,8 +1030,10 @@ gda_connection_add_errorlist (Gda_Connection* cnc, GList* errors)
 {
   g_return_if_fail(IS_GDA_CONNECTION(cnc));
   g_return_if_fail(errors != 0);
-  
+
+#ifndef HAVE_GOBJECT /* FIXME */
   gtk_signal_emit(GTK_OBJECT(cnc), gda_connection_signals[CONNECTION_ERROR], errors);
+#endif
 }
 
 glong
