@@ -1,19 +1,20 @@
 /* GDA Common Library
  * Copyright (C) 2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #if !defined(__gda_common_h__)
@@ -23,13 +24,6 @@
  * This is the main header file for the libgda-common library
  */
 
-#if defined(HAVE_CONFIG_H)
-#  include <config.h>
-#endif
-#include <orb/orb.h>
-#include <gnome.h>
-#include <liboaf/liboaf.h>
-
 #include <gda-corba.h>
 #include <gda-log.h>
 #include <gda-config.h>
@@ -40,4 +34,4 @@
 
 void gda_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);
 
-#endif
\ No newline at end of file
+#endif
