@@ -1,23 +1,35 @@
 /* GNOME DB Common Library
  * Copyright (C) 2000 Rodrigo Moya
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
-#include "gda-common.h"
+#include "config.h"
+#include "gda-config.h"
+
+/* GConf declares some types in gconf/gconf-glib-public.h that are
+ * already defined in glib.h, if we use glib 1.3. The next 3 lines
+ * are needed to prevent this. */
+#ifdef HAVE_GOBJECT
+#  define GCONF_GCONF_GLIB_PUBLIC_H 
+#endif
+
 #include <gconf/gconf.h>
+#include <liboaf/liboaf.h>
+#include "gda-corba.h"
 
 static GConfEngine* conf_engine = NULL;
 
@@ -26,6 +38,8 @@ get_conf_engine (void)
 {
   if (!conf_engine)
     {
+      /* initialize GConf */
+      if (!gconf_is_initialized()) gconf_init(0, NULL, NULL);
       conf_engine = gconf_engine_get_default();
     }
   return conf_engine;
@@ -38,7 +52,7 @@ get_conf_engine (void)
 gchar *
 gda_config_get_string (const gchar *path)
 {
-  return gconf_get_string(get_conf_engine(), path, NULL);
+  return gconf_engine_get_string(get_conf_engine(), path, NULL);
 }
 
 /**
@@ -48,7 +62,7 @@ gda_config_get_string (const gchar *path)
 gint
 gda_config_get_int (const gchar *path)
 {
-  return gconf_get_int(get_conf_engine(), path, NULL);
+  return gconf_engine_get_int(get_conf_engine(), path, NULL);
 }
 
 /**
@@ -58,7 +72,7 @@ gda_config_get_int (const gchar *path)
 gdouble
 gda_config_get_float (const gchar *path)
 {
-  return gconf_get_float(get_conf_engine(), path, NULL);
+  return gconf_engine_get_float(get_conf_engine(), path, NULL);
 }
 
 /**
@@ -68,7 +82,7 @@ gda_config_get_float (const gchar *path)
 gboolean
 gda_config_get_boolean (const gchar *path)
 {
-  return gconf_get_bool(get_conf_engine(), path, NULL);
+  return gconf_engine_get_bool(get_conf_engine(), path, NULL);
 }
 
 /**
@@ -79,7 +93,7 @@ gda_config_get_boolean (const gchar *path)
 void
 gda_config_set_string (const gchar *path, const gchar *new_value)
 {
-  gconf_set_string(get_conf_engine(), path, new_value, NULL);
+  gconf_engine_set_string(get_conf_engine(), path, new_value, NULL);
 }
 
 /**
@@ -90,7 +104,7 @@ gda_config_set_string (const gchar *path, const gchar *new_value)
 void
 gda_config_set_int (const gchar *path, gint new_value)
 {
-  gconf_set_int(get_conf_engine(), path, new_value, NULL);
+  gconf_engine_set_int(get_conf_engine(), path, new_value, NULL);
 }
 
 /**
@@ -101,7 +115,7 @@ gda_config_set_int (const gchar *path, gint new_value)
 void
 gda_config_set_float (const gchar *path, gdouble new_value)
 {
-  gconf_set_float(get_conf_engine(), path, new_value, NULL);
+  gconf_engine_set_float(get_conf_engine(), path, new_value, NULL);
 }
 
 /**
@@ -112,7 +126,7 @@ gda_config_set_float (const gchar *path, gdouble new_value)
 void
 gda_config_set_boolean (const gchar *path, gboolean new_value)
 {
-  gconf_set_bool(get_conf_engine(), path, new_value, NULL);
+  gconf_engine_set_bool(get_conf_engine(), path, new_value, NULL);
 }
 
 /**
@@ -135,7 +149,7 @@ gda_config_remove_section (const gchar *path)
 void
 gda_config_remove_key (const gchar *path)
 {
-  gconf_unset(get_conf_engine(), path, NULL);
+  gconf_engine_unset(get_conf_engine(), path, NULL);
 }
 
 /**
@@ -148,7 +162,29 @@ gda_config_remove_key (const gchar *path)
 gboolean
 gda_config_has_section (const gchar *path)
 {
-  return gconf_dir_exists(get_conf_engine(), path, NULL);
+  return gconf_engine_dir_exists(get_conf_engine(), path, NULL);
+}
+
+/**
+ * gda_config_has_key
+ * @path: path to the configuration key
+ *
+ * Check whether the given key exists in the configuration system
+ */
+gboolean
+gda_config_has_key (const gchar *path)
+{
+  GConfValue* value;
+  
+  g_return_val_if_fail(path != NULL, FALSE);
+  
+  value = gconf_engine_get(get_conf_engine(), path, NULL);
+  if (value)
+    {
+      gconf_value_free(value);
+      return TRUE;
+    }
+  return FALSE;
 }
 
 /**
@@ -191,14 +227,18 @@ gda_config_list_sections (const gchar *path)
 
   g_return_val_if_fail(path != NULL, NULL);
   
-  slist = gconf_all_dirs(get_conf_engine(), path, NULL);
+  slist = gconf_engine_all_dirs(get_conf_engine(), path, NULL);
   if (slist)
     {
       GSList* node;
       
       for (node = slist; node != NULL; node = g_slist_next(node))
         {
-          ret = g_list_append(ret, g_strdup(node->data));
+          gchar* section_name = strrchr((const char *) node->data, '/');
+          if (section_name)
+            {
+              ret = g_list_append(ret, g_strdup(section_name + 1));
+            }
         }
       g_slist_free(slist);
     }
@@ -216,14 +256,15 @@ gda_config_list_keys (const gchar *path)
 
   g_return_val_if_fail(path != NULL, NULL);
   
-  slist = gconf_all_entries(get_conf_engine(), path, NULL);
+  slist = gconf_engine_all_entries(get_conf_engine(), path, NULL);
   if (slist)
     {
       GSList* node;
       
       for (node = slist; node != NULL; node = g_slist_next(node))
         {
-          ret = g_list_append(ret, g_strdup(node->data));
+          g_warning("adding key %s", (gchar *) node->data);
+          ret = g_list_append(ret, g_strdup((gchar *) node->data));
         }
       g_slist_free(slist);
     }
@@ -285,16 +326,6 @@ gda_provider_copy (Gda_Provider* provider)
   if (provider->location) retval->location = g_strdup(provider->location);
   if (provider->repo_id) retval->repo_id = g_strdup(provider->repo_id);
   if (provider->type) retval->type = g_strdup(provider->type);
-  if (provider->main_config)
-    retval->main_config = g_strdup(provider->main_config);
-  if (provider->users_list_config)
-    retval->users_list_config = g_strdup(provider->users_list_config);
-  if (provider->users_ac_config)
-    retval->users_ac_config = g_strdup(provider->users_ac_config);
-  if (provider->db_config)
-    retval->db_config = g_strdup(provider->db_config);
-  if (provider->dsn_config)
-    retval->dsn_config = g_strdup(provider->dsn_config);
   
   return retval;
 }
@@ -317,11 +348,17 @@ gda_provider_free (Gda_Provider* provider)
   if (provider->username) g_free((gpointer) provider->username);
   if (provider->hostname) g_free((gpointer) provider->hostname);
   if (provider->domain) g_free((gpointer) provider->domain);
-  if (provider->main_config) g_free((gpointer) provider->main_config);
-  if (provider->users_list_config) g_free((gpointer) provider->users_list_config);
-  if (provider->users_ac_config) g_free((gpointer) provider->users_ac_config);
-  if (provider->db_config) g_free((gpointer) provider->db_config);
-  if (provider->dsn_config) g_free((gpointer) provider->dsn_config);
+  if (provider->dsn_params)
+    {
+      GList* node;
+      
+      while ((node = g_list_first(provider->dsn_params)))
+        {
+          gchar* str = (gchar *) node->data;
+          provider->dsn_params = g_list_remove(provider->dsn_params, (gpointer) str);
+          g_free((gpointer) str);
+        }
+    }
 
   g_free(provider);
 }
@@ -349,33 +386,38 @@ gda_provider_list (void)
     {
       for (i = 0; i < servlist->_length; i++)
         {
+          gchar* dsn_params;
+          
           provider = gda_provider_new();
           provider->name = g_strdup(servlist->_buffer[i].iid);
           provider->location = g_strdup(servlist->_buffer[i].location_info);
-#if defined(USING_OLD_OAF)
-          provider->comment = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "description");
-          provider->repo_id = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "repo_ids");
-# else
           provider->comment = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "description");
           provider->repo_id = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "repo_ids");
-# endif
           provider->type = g_strdup(servlist->_buffer[i].server_type);
           provider->username = g_strdup(servlist->_buffer[i].username);
           provider->hostname = g_strdup(servlist->_buffer[i].hostname);
           provider->domain = g_strdup(servlist->_buffer[i].domain);
-#if defined(USING_OLD_OAF)
-          provider->main_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "gda-main-config");
-          provider->users_list_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "gda-users-list-config");
-          provider->users_ac_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "gda-users-ac-config");
-          provider->db_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "gda-db-config");
-          provider->dsn_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].attrs, "gda-dsn-config");
-#else
-          provider->main_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda-main-config");
-          provider->users_list_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda-users-list-config");
-          provider->users_ac_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda-users-ac-config");
-          provider->db_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda-db-config");
-          provider->dsn_config = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda-dsn-config");
-#endif
+
+          /* get list of available DSN params */
+          provider->dsn_params = NULL;
+          dsn_params = gda_corba_get_oaf_attribute(servlist->_buffer[i].props, "gda_params");
+          if (dsn_params)
+            {
+              gint    cnt = 0;
+              gchar** arr = g_strsplit(dsn_params, ";", 0);
+              
+              if (arr)
+                {
+                  while (arr[cnt] != NULL)
+                    {
+                      provider->dsn_params = g_list_append(provider->dsn_params, g_strdup(arr[cnt]));
+                      cnt++;
+                    }
+                  g_strfreev(arr);
+                }
+              g_free((gpointer) dsn_params);
+            }
+
           retval = g_list_append(retval, (gpointer) provider);
         }
 
@@ -568,6 +610,27 @@ gda_dsn_free (Gda_Dsn *dsn)
   g_free((gpointer) dsn);
 }
 
+/**
+ * gda_dsn_copy
+ */
+Gda_Dsn *
+gda_dsn_copy (Gda_Dsn *dsn)
+{
+  Gda_Dsn* ret;
+
+  g_return_val_if_fail(dsn != NULL, NULL);
+
+  ret = gda_dsn_new();
+  ret->gda_name = g_strdup(dsn->gda_name);
+  ret->provider = g_strdup(dsn->provider);
+  ret->dsn_str = g_strdup(dsn->dsn_str);
+  ret->description = g_strdup(dsn->description);
+  ret->username = g_strdup(dsn->username);
+  ret->config = g_strdup(dsn->config);
+
+  return ret;
+}
+
 /**
  * gda_dsn_find_by_name
  * @dsn_name: data source name
