@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-connection.c,v 1.1.1.1 2000/08/10 09:32:38 rodrigo Exp $
+ * $Id: gda-sybase-connection.c,v 1.5 2000/11/21 19:57:13 holger Exp $
  *
  * GNOME DB Sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -22,6 +22,22 @@
  */
 
 // $Log: gda-sybase-connection.c,v $
+// Revision 1.5  2000/11/21 19:57:13  holger
+// 2000-11-21 Holger Thon <holger@gidayu.max.uni-duisburg.de>
+//
+// 	- Fixed missing parameter in gda-sybase-server
+// 	- Removed ct_diag/cs_diag stuff completly from tds server
+//
+// Revision 1.4  2000/10/06 19:24:45  menthos
+// Added Swedish entry to configure.in and changed some C++-style comments causing problems to
+// C-style.
+//
+// Revision 1.3  2000/10/04 08:43:14  rodrigo
+// Fixed untranslatable strings
+//
+// Revision 1.2  2000/10/04 08:40:05  rodrigo
+// Fixed untranslatable strings
+//
 // Revision 1.1.1.1  2000/08/10 09:32:38  rodrigo
 // First version of libgda separated from GNOME-DB
 //
@@ -781,16 +797,17 @@ gda_sybase_connection_reopen(Gda_ServerConnection *cnc)
     return FALSE;
   }
   
-  // Now we've got an initialized CS_CONTEXT and an allocated CS_COMMAND
-  // and maybe setup the locale, so we can setup error handling
-  //   For inline messages handling:
-  //     Uncomment all following gda_sybase_messages_install conditions
-  //     for handling messages inline.
-  //     Do comment all conditions with gda_sybase_install_error_messages then!
-  //
-  //   For callback messages handling:
-  //     Uncomment all following gda_sybase_install_error_messages conditions.
-  //     Do comment all conditions with gda_sybase_messages_install then!
+  /* Now we've got an initialized CS_CONTEXT and an allocated CS_COMMAND
+     and maybe setup the locale, so we can setup error handling
+       For inline messages handling:
+         Uncomment all following gda_sybase_messages_install conditions
+	 for handling messages inline.
+	 Do comment all conditions with gda_sybase_install_error_messages then!
+
+       For callback messages handling:
+         Uncomment all following gda_sybase_install_error_messages conditions.
+	 Do comment all conditions with gda_sybase_messages_install then!
+  */
   if (gda_sybase_messages_install(cnc) != TRUE) {
     return FALSE;
   }
@@ -869,9 +886,10 @@ gda_sybase_connection_reopen(Gda_ServerConnection *cnc)
 		       "Could not request servername");
     return FALSE;
   } else {
-    gda_log_message(_("%sonnected to '%s'"),
-		    (first_connection == FALSE) ? "Rec" : "C",
-		    buf);
+    if (first_connection == FALSE)
+      gda_log_message(_("Reconnected to '%s'"), buf);
+    else
+      gda_log_message(_("Connected to %s"), buf);
     if (scnc->database) {
       scnc->ret = gda_sybase_connection_select_database(cnc, scnc->database);
       if (scnc->ret != CS_SUCCEED) {
@@ -968,7 +986,7 @@ gda_sybase_connection_select_database(Gda_ServerConnection *cnc,
     return CS_SUCCEED;
   }
   
-  gda_log_error(_("%s: use command failed"));
+  gda_log_error(_("%s: use command failed"), __PRETTY_FUNCTION__);
   return CS_FAIL;
 }
 
